@@ -1,18 +1,13 @@
 #' Weighted residuals (WRES) and conditional WRES (CWRES) plotted against the
-#' independent variable (IDV) or the population predictions (PRED) for Xpose 4
+#' independent variable (IDV)
 #' 
-#' These functions graphically compare WRES and CWRES as plotted against the
-#' independent variable or the population predictions.
-#' 
-#' This function creates plots of WRES and CWRES, presented side-by-side for
-#' comparison.
-#' 
-#' Conditional weighted residuals (CWRES) require some extra steps to
-#' calculate. See \code{\link{compute.cwres}} for details.
-#' 
-#' A wide array of extra options controlling xyplots are available. See
-#' \code{\link{xpose.plot.default}} and \code{\link{xpose.panel.default}} for
-#' details.
+#' A graphical comparison  between the WRES and CWRES as plotted against the
+#' independent variable. Conditional weighted residuals (CWRES) require 
+#' some extra steps to calculate. Either add \code{CWRES} to your NONMEM 
+#' table files or compute them using the information proveded in 
+#' \code{\link{compute.cwres}}. A wide array of extra options controlling 
+#' xyplots are available. See \code{\link{xpose.plot.default}} and 
+#' \code{\link{xpose.panel.default}} for details.
 #' 
 #' @param object An xpose.data object.
 #' @param ylb A string giving the label for the y-axis. \code{NULL} if none.
@@ -21,28 +16,19 @@
 #' @param smooth A \code{NULL} value indicates that no superposed line should
 #' be added to the graph. If \code{TRUE} then a smooth of the data will be
 #' superimposed.
-#' @param scales scales is passed to \code{xpose.plot.default}
-#' @param \dots Other arguments passed to \code{link[lattice]{xyplot}}.
+#' @param scales scales is passed to  \code{\link{xpose.plot.default}}.
+#' @param \dots Other arguments passed to \code{\link{xpose.plot.default}}.
 #' @return A compound xyplot.
 #' @author Niclas Jonsson & Andrew Hooker
 #' @seealso \code{\link{xpose.plot.default}},
 #' \code{\link{xpose.panel.default}}, \code{\link[lattice]{xyplot}},
 #' \code{\link{xpose.prefs-class}}, \code{\link{xpose.data-class}},
 #' \code{\link{compute.cwres}}
-#' @examples
-#' ## Here we load the example xpose database 
-#' xpdb <- simpraz.xpdb
-#' 
-#' cwres.wres.vs.idv(xpdb)
-#' @name cwres_wres_vs_x
 #' @family specific functions 
-NULL
-
-
-
+#' @examples
+#' cwres.wres.vs.idv(simpraz.xpdb)
 #' @export  
-#' @describeIn cwres_wres_vs_x Weighted residuals (WRES) and conditional WRES (CWRES) plotted against the
-#' independent variable (IDV)
+
 cwres.wres.vs.idv <-
   function(object,
            ylb  = "Residuals",
